@@ -99,6 +99,11 @@ st_crs.default = function(x, ...) NA_crs_
 	x
 }
 
+valid_proj4string = function(p4s) {
+	stopifnot(is.character(p4s))
+	structure(CPL_proj_is_valid(p4s), names = c("valid", "result"))
+}
+
 # return crs object from crs, integer, or character string
 make_crs = function(x) {
 	if (is.na(x))
@@ -107,9 +112,12 @@ make_crs = function(x) {
 		x
 	else if (is.numeric(x)) 
 		CPL_crs_from_epsg(as.integer(x))
-	else if (is.character(x))
+	else if (is.character(x)) {
+		is_valid = valid_proj4string(x) 
+		if (! is_valid$valid)
+			stop(paste0("invalid crs: ", x, ", reason: ", is_valid$result))
 		CPL_crs_from_proj4string(x)
-	else
+	} else
 		stop(paste("cannot create a crs from an object of class", class(x)))
 }
 
@@ -160,3 +168,16 @@ st_is_longlat = function(x) {
 	else
 		length(grep("+proj=longlat", crs$proj4string)) > 0
 }
+
+crs_pars = function(x) {
+	ret = structure(CPL_crs_pars(x$proj4string), 
+		names = c("SemiMajor", "InvFlattening", "units_gdal", "IsVertical"))
+	ret$SemiMajor = ret$SemiMajor * make_unit("m")
+	ret$ud_unit = switch(ret$units_gdal,
+		"Meter"                = make_unit("m"),
+		"Foot_US"              = make_unit("US_survey_foot"),
+		"Foot (International)" = make_unit("ft"),
+		"degree"               = make_unit("arc_degree"),
+		stop("unknown unit: please file an issue at http://github.com/edzer/sfr/"))
+	ret
+}
