@@ -7,10 +7,11 @@
 #' @param geom_column character or integer: indicator of name or position of the geometry column; if not provided, the last column of type character is chosen
 #' @param EWKB logical; is the WKB is of type EWKB? defaults to TRUE if \code{conn} is of class code{PostgreSQLConnection} or \code{PqConnection}
 #' @examples 
-#' if (Sys.getenv("USER") %in% c("travis", "edzer")) {
+#' if (Sys.getenv("USER") %in% c("edzer", "travis")) {
 #'   library(RPostgreSQL)
 #'   conn = dbConnect(PostgreSQL(), dbname = "postgis")
 #'   x = st_read_db(conn, "meuse", query = "select * from meuse limit 3;")
+#'   x = st_read_db(conn, table = "public.meuse")
 #'   print(st_crs(x)) # SRID resolved by the database, not by GDAL!
 #'   dbDisconnect(conn)
 #' }
@@ -27,17 +28,21 @@ st_read_db = function(conn = NULL, table, query = paste("select * from ", table,
 		gc = try(dbReadTable(conn, "geometry_columns"))
 		geom_column = if (class(gc) == "try-error" || missing(table))
 				tail(which(sapply(tbl, is.character)), 1) # guess it's the last character column
-			else
-				gc [ gc$f_table_name == table, "f_geometry_column"]
+			else {
+				tbl_name = tail(strsplit(table, ".", fixed = TRUE)[[1]], 1)
+				gc [ gc$f_table_name == tbl_name, "f_geometry_column"]
+			}
 	}
 	crs = if (missing(table)) {
 			warning("argument table missing: returning object without crs")
 			NA_crs_
 		} else {
-			SRID = dbGetQuery(conn, paste0("select srid from geometry_columns where f_table_name = '", table, "';"))[[1]]
+			tbl_name = tail(strsplit(table, ".", fixed = TRUE)[[1]], 1)
+			SRID = dbGetQuery(conn, paste0("select srid from geometry_columns where f_table_name = '",
+				tbl_name, "';"))[[1]]
 			ret = dbGetQuery(conn, paste("select proj4text from spatial_ref_sys where srid =", SRID, ";"))
 			if (nrow(ret))
-				ret[[1]]
+				make_crs(ret[[1]])
 			else
 				NA_crs_
 		}
@@ -62,7 +67,7 @@ st_read_db = function(conn = NULL, table, query = paste("select * from ", table,
 #' @param debug logical; print SQL statements to screen before executing them.
 #' @export
 #' @examples
-#' if (Sys.getenv("USER") %in% c("travis", "edzer")) {
+#' if (Sys.getenv("USER") %in% c("edzer", "travis")) {
 #'   library(sp)
 #'   data(meuse)
 #'   sf = st_as_sf(meuse, coords = c("x", "y"), crs = 28992)
@@ -92,7 +97,7 @@ st_write_db = function(conn = NULL, obj, table = substitute(obj), geom_name = "w
 	dbWriteTable(conn, table, df, ...)
 	geom = st_geometry(obj)
 	DIM = nchar(class(geom[[1]])[1]) # FIXME: is this correct? XY, XYZ, XYZM
-	SRID = attr(obj, "epsg")
+	SRID = st_crs(geom)$epsg
 	if (is.null(SRID) || is.na(SRID))
 		SRID = 0
 	TYPE = class(geom[[1]])[2]
@@ -108,14 +113,15 @@ st_write_db = function(conn = NULL, obj, table = substitute(obj), geom_name = "w
 		wkt = st_as_text(geom)
 		for (r in seq_along(rn)) {
 			cmd = DEBUG(paste0("UPDATE ", table, " SET ", geom_name, 
-				" = ST_GeomFromText('", wkt[r], "') WHERE \"row.names\" = '", rn[r], "';"))
+				" = ST_GeomFromText('", wkt[r], "',",SRID,") WHERE \"row.names\" = '", rn[r], "';"))
 			dbGetQuery(conn, cmd)
 		}
 	} else {
-		wkb = st_as_binary(geom)
+		wkb = st_as_binary(geom, EWKB = TRUE)
 		for (r in seq_along(rn)) {
-			cmd = DEBUG(paste0("UPDATE ", table, " SET ", geom_name, " = '", CPL_raw_to_hex(wkb[[r]]), 
-				"' WHERE \"row.names\" = '", rn[r], "';"))
+			cmd = DEBUG(paste0("UPDATE ", table, " SET ",
+                            geom_name, " = '", CPL_raw_to_hex(wkb[[r]]), 
+                            "' WHERE \"row.names\" = '", rn[r], "';"))
 			dbGetQuery(conn, cmd)
 		}
 	}
