@@ -9,8 +9,9 @@
 #' @param iGeomField integer; in case of multiple geometry fields, which one to take?
 #' @param type integer; ISO number of desired simple feature type; see details. If left zero, in case of mixed feature geometry types, conversion to the highest numeric type value found will be attempted.
 #' @param promote_to_multi logical; in case of a mix of LineString and MultiLineString, or of Polygon and MultiPolygon, convert all to the Multi variety; defaults to \code{TRUE}
-#' @details for iGeomField, see also \url{https://trac.osgeo.org/gdal/wiki/rfc41_multiple_geometry_fields}; for \code{type} values see \url{https://en.wikipedia.org/wiki/Well-known_text#Well-known_binary}, but note that not every target value may lead to succesful conversion. The typical conversion from POLYGON (3) to MULTIPOLYGON (6) should work; the other way around (type=3), secondary rings from MULTIPOLYGONS may be dropped without warnings. 
 #' @param stringsAsFactors logical; logical: should character vectors be converted to factors?  The `factory-fresh' default is \code{TRUE}, but this can be changed by setting \code{options(stringsAsFactors = FALSE)}.  
+#' @param int64_as_string logical; if TRUE, Int64 attributes are returned as string; if FALSE, they are returned as double and a warning is given when precision is lost (i.e., values are larger than 2^53).
+#' @details for iGeomField, see also \url{https://trac.osgeo.org/gdal/wiki/rfc41_multiple_geometry_fields}; for \code{type} values see \url{https://en.wikipedia.org/wiki/Well-known_text#Well-known_binary}, but note that not every target value may lead to succesful conversion. The typical conversion from POLYGON (3) to MULTIPOLYGON (6) should work; the other way around (type=3), secondary rings from MULTIPOLYGONS may be dropped without warnings. 
 #' @return object of class \link{sf} when a layer was succesfully read; in case argument \code{layer} is missing and data source \code{dsn} does not contain a single layer, an object of class \code{sf_layers} is returned with the layer names, each with their geometry type(s). Note that the number of layers may also be zero.
 #' @examples
 #' if (Sys.getenv("USER") %in% c("edzer", "travis")) { # load meuse to postgis
@@ -28,7 +29,8 @@
 #' @note The use of \code{system.file} in examples make sure that examples run regardless where R is installed: typical users will not use \code{system.file} but give the file name directly, either with full path or relative to the current working directory (see \link{getwd}). "Shapefiles" consist of several files with the same basename that reside in the same directory, only one of them having extension \code{.shp}. 
 #' @export
 st_read = function(dsn, layer, ..., options = NULL, quiet = FALSE, iGeomField = 1L, type = 0,
-		promote_to_multi = TRUE, stringsAsFactors = default.stringsAsFactors()) {
+		promote_to_multi = TRUE, stringsAsFactors = default.stringsAsFactors(), 
+		int64_as_string = FALSE) {
 
 	if (missing(dsn))
 		stop("dsn should specify a data source or filename")
@@ -40,7 +42,7 @@ st_read = function(dsn, layer, ..., options = NULL, quiet = FALSE, iGeomField =
 		dsn = normalizePath(dsn)
 
 	x = CPL_read_ogr(dsn, layer, as.character(options), quiet, iGeomField - 1L, type, 
-		promote_to_multi)
+		promote_to_multi, int64_as_string)
 	which.geom = which(sapply(x, function(f) inherits(f, "sfc")))
 	nm = names(x)[which.geom]
 	geom = x[[which.geom]]
@@ -63,13 +65,14 @@ st_read = function(dsn, layer, ..., options = NULL, quiet = FALSE, iGeomField =
 #' @param obj object of class \code{sf} or \code{sfc}
 #' @param dsn data source name (interpretation varies by driver - for some drivers, dsn is a file name, but may also be a folder or contain a database name)
 #' @param layer layer name (varies by driver, may be a file name without extension); if layer is missing, the \link{basename} of \code{dsn} is taken.
-#' @param driver character; OGR driver name to be used, if missing, a driver name is guessed from \code{dsn}.
+#' @param driver character; driver name to be used, if missing, a driver name is guessed from \code{dsn}; \code{st_drivers()} returns the drivers that are available with their properties; links to full driver documentation are found at \url{http://www.gdal.org/ogr_formats.html}.
 #' @param ... ignored
 #' @param dataset_options character; driver dependent dataset creation options; multiple options supported.
 #' @param layer_options character; driver dependent layer creation options; multiple options supported.
 #' @param quiet logical; suppress info on name, driver, size and spatial reference
 #' @param factorsAsCharacter logical; convert \code{factor} objects into character strings (default), else into numbers by \code{as.numeric}.
 #' @details columns (variables) of a class not supported are dropped with a warning.
+#' @seealso \link{st_drivers}
 #' @examples
 #' if (Sys.getenv("USER") %in% c("edzer", "travis")) { # load meuse to postgis
 #'  library(sp)
@@ -82,7 +85,7 @@ st_read = function(dsn, layer, ..., options = NULL, quiet = FALSE, iGeomField =
 #' nc = st_read(system.file("shape/nc.shp", package="sf"))
 #' st_write(nc, "nc.shp")
 #' @export
-st_write = function(obj, dsn, layer = basename(dsn), driver = guess_driver(dsn), ..., 
+st_write = function(obj, dsn, layer = basename(dsn), driver = guess_driver_can_write(dsn), ..., 
 		dataset_options = NULL, layer_options = NULL, quiet = FALSE, factorsAsCharacter = TRUE) {
 
 	if (inherits(obj, "sfc"))
@@ -174,65 +177,108 @@ st_layers = function(dsn, options = character(0), do_count = FALSE) {
 #' @name st_layers
 #' @export
 st_list = function(dsn, options = character(0), do_count = FALSE) {
-	.Deprecated("st_layers")
+	.Deprecated("st_layers") # nocov
 }
 
 guess_driver = function(dsn) {
-    ext_map <- matrix (c(
-                       "bna",    "BNA",
-                       "csv",    "CSV",
-                       "e00",    "AVCE00",
-                       "gdb",    "FileGDB",
-                       "geojson","GeoJSON",
-                       "gml",    "GML",
-                       "gmt",    "GMT",
-                       "gpkg",   "GPKG",
-                       "gps",    "GPSBabel",
-                       "gtm",    "GPSTrackMaker",   
-                       "gxt",    "Geoconcept",
-                       "jml",    "JML",
-                       "map",    "WAsP",
-                       "mdb",    "Geomedia",
-                       "nc",     "netCDF",
-                       "ods",    "ODS",
-                       "osm",    "OSM",
-                       "pbf",    "OSM",
-                       "shp",    "ESRI Shapefile",
-                       "sqlite", "SQLite",
-                       "vdv",    "VDV",
-                       "xls",    "xls",
-                       "xlsx",   "XLSX"
-                     ), ncol = 2, byrow = TRUE)
-	prefix_map = matrix(c(
-                       "couchdb", "CouchDB",
-                       "DB2ODBC", "DB2ODBC",
-                       "DODS",    "DODS",
-                       "GFT",     "GFT",
-                       "MSSQL",   "MSSQLSpatial",
-                       "MySQL",   "MySQL",
-                       "OCI",     "OCI",
-                       "ODBC",    "ODBC",
-                       "PG",      "PostgreSQL",
-                       "SDE",     "SDE"
-                     ), ncol = 2, byrow = TRUE)
-	drv = ext_map[,2]
-	names(drv) = ext_map[,1]
-	prfx = prefix_map[,2]
-	names(prfx) = tolower(prefix_map[,1])
-
+  stopifnot(is.character(dsn))
+  stopifnot(length(dsn) == 1)
+  
 	# find match: try extension first
-	drv = drv[tolower(tools::file_ext(dsn))]
-	if (is.na(drv)) { # try prefix, like "PG:dbname=sth"
-		if (length(grep(":", dsn)))
-			drv = prfx[tolower(strsplit(dsn, ":")[[1]][1])]
-		if (is.na(drv)) # no match
-			stop("no driver specified, cannot guess driver from dsn")
+	drv = extension_map[tolower(tools::file_ext(dsn))]
+	if (any(grep(":", gsub(":/", "/", dsn)))) {
+			drv = prefix_map[tolower(strsplit(dsn, ":")[[1]][1])]
+	}
+	drv <- unlist(drv)
+	
+	if (is.null(drv)) {
+	  # no match
+	  return(NA)
 	}
-	drivers = st_drivers()
-	i = match(drv, drivers$name)
-	if (is.na(i))
-		stop(paste("guess_driver:", drv, "not available in supported drivers, see `st_drivers()'"))
-	if (! drivers[i, "write"])
-		stop(paste("Driver", drv, "has no write capability, see `st_drivers()'"))
 	drv
 }
+
+guess_driver_can_write = function(dns, drv = guess_driver(dns)) {
+  if(is.na(drv)) {
+    stop("Could not guess driver for ", dns, call. = FALSE)
+  }
+  if(!is_driver_available(drv)) {
+    stop(unlist(drv), " driver not available in supported drivers, see `st_drivers()'", call. = FALSE)
+  }
+  if(!is_driver_can(drv, operation = "write")) {
+    stop("Driver ", drv, " cannot write. see `st_drivers()'", call. = FALSE)
+  }
+  return(drv)
+}
+
+#' Check if driver is available
+#' 
+#' Search through the driver table if driver is listed
+#' @param drv character. Name of driver
+#' @param drivers data.frame. Table containing driver names and support. Default
+#' is from \code{\link{st_drivers}}
+is_driver_available = function(drv, drivers = st_drivers()) {
+  i = match(drv, drivers$name)
+  if (is.na(i))
+    return(FALSE)
+  
+  return(TRUE)
+}
+
+#' Check if a driver can perform an action
+#' 
+#' Search through the driver table to match a driver name with 
+#' an action (e.g. \code{"write"}) and check if the action is supported.
+#' @param drv character. Name of driver
+#' @param drivers data.frame. Table containing driver names and support. Default
+#' is from \code{\link{st_drivers}}
+#' @param operation character. What action to check
+is_driver_can = function(drv, drivers = st_drivers(), operation = "write") {
+  stopifnot(operation %in% names(drivers))
+  i = match(drv, drivers$name)
+  if (!drivers[i, operation])
+    return(FALSE)
+  
+  return(TRUE)
+}
+
+#' Map extension to driver
+#' @docType data
+extension_map <- list(
+     "bna" = "BNA",
+     "csv" = "CSV",
+     "e00" = "AVCE00",
+     "gdb" = "OpenFileGDB",
+     "geojson" = "GeoJSON",
+     "gml" = "GML",
+     "gmt" = "GMT",
+     "gpkg" = "GPKG",
+     "gps" = "GPSBabel",
+     "gtm" = "GPSTrackMaker",   
+     "gxt" = "Geoconcept",
+     "jml" = "JML",
+     "map" = "WAsP",
+     "mdb" = "Geomedia",
+     "nc" = "netCDF",
+     "ods" = "ODS",
+     "osm" = "OSM",
+     "pbf" = "OSM",
+     "shp" = "ESRI Shapefile",
+     "sqlite" = "SQLite",
+     "vdv" = "VDV",
+     "xls" = "xls",
+     "xlsx" = "XLSX")
+
+#' Map prefix to driver
+#' @docType data
+prefix_map <- list(
+  "couchdb" = "CouchDB",
+  "db2odbc" = "DB2ODBC",
+  "dods" = "DODS",
+  "gft" = "GFT",
+  "mssql" = "MSSQLSpatial",
+  "mysql" = "MySQL",
+  "oci" = "OCI",
+  "odbc" = "ODBC",
+  "pg" = "PostgreSQL",
+  "sde" = "SDE") 
