@@ -48,6 +48,9 @@ st_as_sf.data.frame = function(x, ..., relation_to_geometry = NA_character_, coo
 	st_sf(x, ..., relation_to_geometry = relation_to_geometry)
 }
 
+#' @export
+st_as_sf.sf = function(x, ...) x
+
 #' Get, set, or replace geometry from an sf object
 #' 
 #' Get, set, or replace geometry from an sf object
@@ -92,9 +95,12 @@ st_geometry.sfg = function(obj, ...) st_sfc(obj)
 
 #' @export
 `st_geometry<-.sf` = function(x, value) {
-	stopifnot(inherits(value, "sfc"))
+	stopifnot(is.null(value) || inherits(value, "sfc"))
 	x[[attr(x, "sf_column")]] <- value
-	x
+	if (is.null(value))
+		data.frame(x)
+	else
+		x
 }
 
 #' Create sf object
@@ -171,6 +177,7 @@ st_sf = function(..., relation_to_geometry = NA_character_, row.names,
 #' @param i record selection, see \link{[.data.frame}
 #' @param j variable selection, see \link{[.data.frame}
 #' @param drop whether to drop to simpler (e.g. vector) representation, see \link{[.data.frame}
+#' @param op character; geometrical operation to apply when \code{i} is a simple feature object
 #' @details "[.sf" will return a \code{data.frame} if the geometry column (of class \code{sfc}) is dropped, an \code{sfc} object if only the geometry column is selected, otherwise the behavior depending on \code{drop} is identical to that of \link{[.data.frame}.
 #' @examples
 #' g = st_sfc(st_point(1:2), st_point(3:4))
@@ -187,19 +194,32 @@ st_sf = function(..., relation_to_geometry = NA_character_, row.names,
 #' g[h,]
 #' h[g,]
 #' @export
-"[.sf" = function(x, i, j, ..., drop) {
+"[.sf" = function(x, i, j, ..., drop = FALSE, op = "intersects") {
+	nargs = nargs()
 	rtg = attr(x, "relation_to_geometry")
 	if (!missing(i) && (inherits(i, "sf") || inherits(i, "sfc")))
-		i = sapply(st_geos_binop("intersects", x, i, ...), length) != 0
+		i = sapply(st_geos_binop(op, x, i, ...), length) != 0
 	sf_column = attr(x, "sf_column")
-	x = NextMethod("[")
+	geom = st_geometry(x)
+	if (!missing(i) && nargs > 2) # e.g. a[3:4,] not a[3:4]
+		geom = geom[i]
+	x = if (missing(j))
+		NextMethod("[") # specifying drop would trigger a warning
+	else
+		NextMethod("[", drop = drop)
 	if (inherits(x, "sfc")) # drop was TRUE, and we selected geom column only
-		return(x)
-	if (!(sf_column %in% names(x))) # geom was deselected
-		return(as.data.frame(x))
-	attr(x, "sf_column") = sf_column
-	attr(x, "relation_to_geometry") = rtg[names(rtg) %in% names(x)]
-	x
+		x
+	else if (! drop) {
+		if (!(sf_column %in% names(x))) { # geom was deselected: make it sticky
+			if (inherits(x, "sf"))
+				x[[sf_column]] = geom
+			else
+				st_geometry(x) = geom
+		}
+		structure(x, "sf_column" = sf_column,
+			"relation_to_geometry" = rtg[names(rtg) %in% names(x)])
+	} else
+		as.data.frame(x)
 }
 
 #' @export
@@ -243,3 +263,8 @@ cbind.sf = function(..., deparse.level = 1) {
 	st_sf(base::cbind.data.frame(...))
 	# do.call(st_sf, list(...))
 }
+
+all_fields = function(x) {
+	x = attr(x, "relation_to_geometry")
+	!(any(is.na(x)) || any(x != "field"))
+}
