@@ -1,3 +1,14 @@
+#' @export
+str.sfc <- function(object,...) {
+	n <- length(object)
+	if (n == 0L)
+		str(object)
+	else {
+		cat(" List of ",n,", printing ")
+		str(object[[1]],...)
+	}
+}
+
 #' @export
 format.sfc = function(x, ..., digits = 30) {
 	sapply(x, format, ..., digits = digits)
@@ -12,7 +23,10 @@ format.sfc = function(x, ..., digits = 30) {
 #' @param crs coordinate reference system: integer with the epsg code, or character with proj4string
 #' @param precision numeric; see \link{st_as_binary}
 #' 
-#' @details a simple feature collection object is a list of class \code{c("stc_TYPE", "sfc")} which contains objects of identical type. This function creates such an object from a list of simple feature objects (of class \code{sfg}), and coerces their type if necessary: collections of XX and MULTIXX are coerced to MULTIXX (with XX: POINT, LINESTRING or POLYGON), other sets are coerced to GEOMETRYCOLLECTION. 
+#' @details a simple feature collection object is a list of class 
+#' \code{c("stc_TYPE", "sfc")} which contains objects of identical type. This 
+#' function creates such an object from a list of simple feature geometries (of 
+#' class \code{sfg}). 
 #' @examples
 #' pt1 = st_point(c(0,1))
 #' pt2 = st_point(c(1,1))
@@ -60,28 +74,6 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0) {
 	st_set_crs(lst, crs)
 }
 
-# coerce XX and MULTIXX mixes to MULTIXX, other mixes to GeometryCollection:
-#coerce_types = function(lst) {
-#	if (!identical(unique(sapply(lst, function(x) class(x)[3L])), "sfg"))
-#		stop("list item(s) not of class sfg") # sanity check
-#	cls = unique(sapply(lst, function(x) class(x)[2L]))
-#	if (length(cls) > 1) {
-#		if (all(cls %in% c("POINT", "MULTIPOINT")))
-#			lapply(lst, 
-#				function(x) if (inherits(x, "POINT")) POINT2MULTIPOINT(x) else x)
-#		else if (all(cls %in% c("POLYGON", "MULTIPOLYGON")))
-#			lapply(lst, 
-#				function(x) if (inherits(x, "POLYGON")) POLYGON2MULTIPOLYGON(x) else x)
-#		else if (all(cls %in% c("LINESTRING", "MULTILINESTRING")))
-#			lapply(lst, 
-#				function(x) if (inherits(x, "LINESTRING")) LINESTRING2MULTILINESTRING(x) else x)
-#		else lapply(lst, 
-#			function(x) if (inherits(x, "GEOMETRYCOLLECTION")) x 
-#				else st_geometrycollection(list(x)))
-#	} else
-#		lst
-#}
-
 #' @export
 "[.sfc" = function(x, i, j, ...) {
 	recompute_bb = !missing(i)
@@ -92,6 +84,8 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0) {
 	a = attributes(old)
 	if (!is.null(names(x)))
 		a$names = names(x)[i]
+	if (!is.null(a$classes))
+		a$classes = a$classes[i]
     attributes(x) = a
 	if (recompute_bb)
 		attr(x, "bbox") = st_bbox(x)
@@ -209,7 +203,7 @@ st_drop_zm <- function(x, ...) UseMethod("st_drop_zm")
 #' @export
 st_drop_zm.sf <- function(x, ...) {
 	st_geometry(x) = st_drop_zm(st_geometry(x))
-	return(x)
+	x
 }
 
 #' @export
