@@ -38,7 +38,7 @@ static void __warningHandler(const char *fmt, ...) {
 }
 
 GEOSContextHandle_t CPL_geos_init(void) {
-    return(initGEOS_r((GEOSMessageHandler) __warningHandler, (GEOSMessageHandler) __errorHandler));
+    return initGEOS_r((GEOSMessageHandler) __warningHandler, (GEOSMessageHandler) __errorHandler);
 }
 
 void CPL_geos_finish(GEOSContextHandle_t ctxt) {
@@ -58,7 +58,7 @@ std::vector<GEOSGeom> geometries_from_sfc(GEOSContextHandle_t hGEOSCtxt, Rcpp::L
 
 Rcpp::List sfc_from_geometry(GEOSContextHandle_t hGEOSCtxt, std::vector<GEOSGeom> geom) {
 	Rcpp::List out(geom.size());
-	for (int i = 0; i < geom.size(); i++) {
+	for (size_t i = 0; i < geom.size(); i++) {
 		size_t size;
 		unsigned char *buf = GEOSGeomToWKB_buf_r(hGEOSCtxt, geom[i], &size);
 		Rcpp::RawVector raw(size);
@@ -121,8 +121,8 @@ Rcpp::List CPL_geos_binop(Rcpp::List sfc0, Rcpp::List sfc1, std::string op, doub
 		ret_list = Rcpp::List::create(out);
 	} else if (op == "distance") { // return double matrix:
 		Rcpp::NumericMatrix out(sfc0.length(), sfc1.length());
-		for (int i = 0; i < gmv0.size(); i++)
-			for (int j = 0; j < gmv1.size(); j++) {
+		for (size_t i = 0; i < gmv0.size(); i++)
+			for (size_t j = 0; j < gmv1.size(); j++) {
 				double dist = -1.0;
 				if (GEOSDistance_r(hGEOSCtxt, gmv0[i], gmv1[j], &dist) == 0)
 					throw std::range_error("GEOS error in GEOSDistance_r");
@@ -187,9 +187,9 @@ Rcpp::List CPL_geos_binop(Rcpp::List sfc0, Rcpp::List sfc1, std::string op, doub
 		else
 			ret_list = Rcpp::List::create(densemat);
 	}
-	for (int i = 0; i < gmv0.size(); i++)
+	for (size_t i = 0; i < gmv0.size(); i++)
 		GEOSGeom_destroy_r(hGEOSCtxt, gmv0[i]);
-	for (int i = 0; i < gmv1.size(); i++)
+	for (size_t i = 0; i < gmv1.size(); i++)
 		GEOSGeom_destroy_r(hGEOSCtxt, gmv1[i]);
 	CPL_geos_finish(hGEOSCtxt);
 	return ret_list;
@@ -272,6 +272,9 @@ Rcpp::List CPL_geos_op(std::string op, Rcpp::List sfc,
 		for (size_t i = 0; i < g.size(); i++)
 			out[i] = preserveTopology ? chkNULL(GEOSTopologyPreserveSimplify_r(hGEOSCtxt, g[i], dTolerance)) :
 					chkNULL(GEOSSimplify_r(hGEOSCtxt, g[i], dTolerance));
+	} else if (op == "linemerge") {
+		for (size_t i = 0; i < g.size(); i++)
+			out[i] = chkNULL(GEOSLineMerge_r(hGEOSCtxt, g[i]));
 	} else if (op == "polygonize") {
 		for (size_t i = 0; i < g.size(); i++)
 			out[i] = chkNULL(GEOSPolygonize_r(hGEOSCtxt, &(g[i]), 1)); // xxx
